@@ -15,7 +15,7 @@ use WebService::Google::Reader::Constants;
 use WebService::Google::Reader::Feed;
 use WebService::Google::Reader::ListElement;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 $VERSION = eval $VERSION;
 
 __PACKAGE__->mk_accessors(qw(
@@ -34,6 +34,7 @@ sub new {
         );
         $self->ua($ua);
     }
+    $ua->ssl_opts(verify_hostname => 0) if $ua->can('ssl_opts');
 
     $self->compress(1);
     $self->debug(0);
@@ -538,6 +539,8 @@ sub _request {
 
     $req->header(authorization => 'GoogleLogin auth=' . $self->auth)
         if $self->auth;
+    $req->header(if_ssl_cert_subject => "/CN=(?i)\Q@{[$req->uri->host]}\E\$")
+        if 'https' eq $req->uri->scheme;
 
     my $res = $self->ua->request($req);
     if ($res->is_error) {
@@ -557,10 +560,9 @@ sub _request {
         $self->error($res->status_line . ' - ' . $res->decoded_content);
         return;
     }
-    else {
-        # Reset the error from previous requests.
-        $self->error(undef);
-    }
+
+    # Reset the error from previous requests.
+    $self->error(undef);
 
     return $res;
 }
@@ -682,7 +684,7 @@ sub _feed {
     if (my $start_time = $params{start_time}) {
         $fields{ot} = $start_time;
     }
-    if (my $order = $params{order} || $params{sort}) {
+    if (my $order = $params{order} || $params{sort} || 'desc') {
         # m = magic/auto; not really sure what that is
         $fields{r} = 'desc' eq $order ? 'n' :
                      'asc'  eq $order ? 'o' : $order;
@@ -812,7 +814,6 @@ WebService::Google::Reader - Perl interface to Google Reader
         my @entries = $feed->entries;
     }
 
-
 =head1 DESCRIPTION
 
 The C<WebService::Google::Reader> module provides an interface to the
